% Auto-generated chapter 41 for malik
% Hadiths in this chapter: 35

\hadithdefcmd{malik}{1500}{حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ جَاءَتِ الْيَهُودُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ أَنَّ رَجُلاً مِنْهُمْ وَامْرَأَةً زَنَيَا فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَجِدُونَ فِي التَّوْرَاةِ فِي شَأْنِ الرَّجْمِ ‏"‏ ‏.‏ فَقَالُوا نَفْضَحُهُمْ وَيُجْلَدُونَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبْتُمْ إِنَّ فِيهَا الرَّجْمَ ‏.‏ فَأَتَوْا بِالتَّوْرَاةِ فَنَشَرُوهَا فَوَضَعَ أَحَدُهُمْ يَدَهُ عَلَى آيَةِ الرَّجْمِ ثُمَّ قَرَأَ مَا قَبْلَهَا وَمَا بَعْدَهَا فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ارْفَعْ يَدَكَ فَرَفَعَ يَدَهُ فَإِذَا فِيهَا آيَةُ الرَّجْمِ فَقَالُوا صَدَقَ يَا مُحَمَّدُ فِيهَا آيَةُ الرَّجْمِ ‏.‏ فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَا ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَرَأَيْتُ الرَّجُلَ يَحْنِي عَلَى الْمَرْأَةِ يَقِيهَا الْحِجَارَةَ ‏.‏\hadithno{1500}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said in the case of an umm walad who injured someone, "The blood-money of that injury is the responsibility of her master from his property, unless the blood-money of the injury is greater than the value of the umm walad. Her master does not have to pay more than her value. That is because when the master of a slave or slave-girl surrenders his slave or slave-girl for an injury which one of them has done, he does not owe any more than that, even if the blood-money is greater. As the master of the umm walad cannot surrender her because of the precedent of the sunna, when he pays her price, it is as if he had surrendered her. He does not have to pay more than that. This is the best of what I have heard about the matter. The master is not obliged to assume responsibility for more than an umm walad's value because of her criminal action." Malik related to me from Nafi that Abdullah ibn Umar said, "The Jews came to the Messenger of Allah, may Allah bless him and grant him peace, and mentioned to him that a man and woman from among them had committed adultery. The Messenger of Allah, may Allah bless him and grant him peace, asked them, 'What do you find in the Torah about stoning?' They said, 'We make their wrong action known and flog them.' Abdullah ibn Salam said, 'You have lied! It has stoning for it, so bring the Torah.' They spread it out and one of them placed his hand over the ayat of stoning. Then he read what was before it and what was after it. Abdullah ibn Salam told him to lift his hand. He lifted his hand and there was the ayat of stoning. They said, 'He has spoken the truth, Muhammad. The ayat of stoning is in it.' So the Messenger of Allah, may Allah bless him and grant him peace, gave the order and they were stoned . " Abdullah ibn Umar added, "I saw the man leaning over the woman to protect her from the stones." Malik commented, "By leaning he meant throwing himself over her so that the stones fell on him}}
\hadithdefcmd{malik}{1501}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ جَاءَ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَقَالَ لَهُ إِنَّ الأَخِرَ زَنَا ‏.‏ فَقَالَ لَهُ أَبُو بَكْرٍ هَلْ ذَكَرْتَ هَذَا لأَحَدٍ غَيْرِي فَقَالَ لاَ ‏.‏ فَقَالَ أَبُو بَكْرٍ فَتُبْ إِلَى اللَّهِ وَاسْتَتِرْ بِسِتْرِ اللَّهِ فَإِنَّ اللَّهَ يَقْبَلُ التَّوْبَةَ عَنْ عِبَادِهِ ‏.‏ فَلَمْ تُقْرِرْهُ نَفْسُهُ حَتَّى أَتَى عُمَرَ بْنَ الْخَطَّابِ فَقَالَ لَهُ مِثْلَ مَا قَالَ لأَبِي بَكْرٍ فَقَالَ لَهُ عُمَرُ مِثْلَ مَا قَالَ لَهُ أَبُو بَكْرٍ فَلَمْ تُقْرِرْهُ نَفْسُهُ حَتَّى جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ إِنَّ الأَخِرَ زَنَا فَقَالَ سَعِيدٌ فَأَعْرَضَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَ مَرَّاتٍ كُلُّ ذَلِكَ يُعْرِضُ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا أَكْثَرَ عَلَيْهِ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَهْلِهِ فَقَالَ ‏"‏ أَيَشْتَكِي أَمْ بِهِ جِنَّةٌ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ وَاللَّهِ إِنَّهُ لَصَحِيحٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبِكْرٌ أَمْ ثَيِّبٌ ‏"‏ ‏.‏ فَقَالُوا بَلْ ثَيِّبٌ يَا رَسُولَ اللَّهِ ‏.‏ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَ ‏.‏\hadithno{1501}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Yahya ibn Said from Said ibn al-Musayyab that a man from the Aslam tribe came to Abu Bakr as-Siddiq and said to him, "I have committed adultery." Abu Bakr said to him, "Have you mentioned this to anyone else?" He said, "No." Abu Bakr said to him, "Then cover it up with the veil of Allah. Allah accepts tawba from his slaves." His self was still unsettled, so he went to Umar ibn al- Khattab. He told him the same as he had said to Abu Bakr, and Umar told him the same as Abu Bakr had said to him. His self was still not settled so he went to the Messenger of Allah, may Allah bless him and grant him peace, and said to him, "I have committed adultery," insistently. The Messenger of Allah, may Allah bless him and grant him peace, turned away from him three times. Each time the Messenger of Allah, may Allah bless him and grant him peace, turned away from him until it became too much. The Messenger of Allah, may Allah bless him and grant him peace, questioned his family, "Does he have an illness which affects his mind, or is he mad?" They said, "Messenger of Allah, by Allah, he is well." The Messenger of Allah, may Allah bless him and grant him peace, said, "Unmarried or married?" They said, "Married, Messenger of Allah." The Messenger of Allah, may Allah bless him and grant him peace, gave the order and he was stoned}}
\hadithdefcmd{malik}{1502}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ مِنْ أَسْلَمَ يُقَالُ لَهُ هَزَّالٌ ‏ "‏ يَا هَزَّالُ لَوْ سَتَرْتَهُ بِرِدَائِكَ لَكَانَ خَيْرًا لَكَ ‏"‏ ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ فَحَدَّثْتُ بِهَذَا الْحَدِيثِ فِي مَجْلِسٍ فِيهِ يَزِيدُ بْنُ نُعَيْمِ بْنِ هَزَّالٍ الأَسْلَمِيِّ فَقَالَ يَزِيدُ هَزَّالٌ جَدِّي وَهَذَا الْحَدِيثُ حَقٌّ ‏.‏\hadithno{1502}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Yahya ibn Said that Said ibn al-Musayyab said, "I have heard that the Messenger of Allah, may Allah bless him and grant him peace, said to a man from the Aslam tribe called Hazzal, 'Hazzal, had you veiled him with your cloak, it would have been better for you.' " Yahya ibn Said said, "I related this hadith in an assembly among whom was Yazid ibn Nuaym ibn Hazzal al-Aslami. Yazid said, 'Hazzal was my grandfather. This hadith is true}}
\hadithdefcmd{malik}{1503}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ أَخْبَرَهُ ‏.‏ أَنَّ رَجُلاً اعْتَرَفَ عَلَى نَفْسِهِ بِالزِّنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَشَهِدَ عَلَى نَفْسِهِ أَرْبَعَ مَرَّاتٍ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَ ‏.‏ قَالَ ابْنُ شِهَابٍ فَمِنْ أَجْلِ ذَلِكَ يُؤْخَذُ الرَّجُلُ بِاعْتِرَافِهِ عَلَى نَفْسِهِ\hadithno{1503}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me that Ibn Shihab informed him that a man confessed that he had committed adultery in the time of the Messenger of Allah, may Allah bless him and grant him peace, and he testified against himself four times, so the Messenger of Allah, may Allah bless him and grant him peace, gave the order and he was stoned. Ibn Shihab said, "Because of this a man is to be taken for his own confession against himself}}
\hadithdefcmd{malik}{1504}{حَدَّثَنِي مَالِكٌ، عَنْ يَعْقُوبَ بْنِ زَيْدِ بْنِ طَلْحَةَ، عَنْ أَبِيهِ، زَيْدِ بْنِ طَلْحَةَ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، أَنَّهُ أَخْبَرَهُ أَنَّ امْرَأَةً جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَتْهُ أَنَّهَا زَنَتْ وَهِيَ حَامِلٌ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبِي حَتَّى تَضَعِي ‏"‏ ‏.‏ فَلَمَّا وَضَعَتْ جَاءَتْهُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اذْهَبِي حَتَّى تُرْضِعِيهِ ‏"‏ ‏.‏ فَلَمَّا أَرْضَعَتْهُ جَاءَتْهُ فَقَالَ ‏"‏ اذْهَبِي فَاسْتَوْدِعِيهِ ‏"‏ ‏.‏ قَالَ فَاسْتَوْدَعَتْهُ ثُمَّ جَاءَتْ فَأَمَرَ بِهَا فَرُجِمَتْ ‏.‏\hadithno{1504}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from Yaqub ibn Zayd ibn Talha from his father Zayd ibn Talha that Abdullah ibn Abi Mulayka informed him that a woman came to the Messenger of Allah, may Allah bless him and grant him peace, and informed him that she had committed adultery and was pregnant. The Messenger of Allah, may Allah bless him and grant him peace, said to her, "Go away until you give birth." When she had given birth, she came to him. The Messenger of Allah, may Allah bless him and grant him peace, said to her, "Go away until you have suckled and weaned the baby." When she had weaned the baby, she came to him. He said, "Go and entrust the baby to someone." She entrusted the baby to someone and then came to him. He gave the order and she was stoned}}
\hadithdefcmd{malik}{1505}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَقَالَ الآخَرُ وَهُوَ أَفْقَهُهُمَا أَجَلْ يَا رَسُولَ اللَّهِ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَائْذَنْ لِي أَنْ أَتَكَلَّمَ ‏.‏ قَالَ ‏"‏ تَكَلَّمْ ‏"‏ ‏.‏ فَقَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا فَزَنَا بِامْرَأَتِهِ فَأَخْبَرَنِي أَنَّ عَلَى ابْنِي الرَّجْمَ فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَبِجَارِيَةٍ لِي ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّ مَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ وَأَخْبَرُونِي أَنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ‏"‏ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ عَلَيْكَ ‏"‏ ‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا وَأَمَرَ أُنَيْسًا الأَسْلَمِيَّ أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ فَإِنِ اعْتَرَفَتْ رَجَمَهَا فَاعْتَرَفَتْ فَرَجَمَهَا ‏.‏\hadithno{1505}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud that Abu Hurayra and Zayd ibn Khalid al-Juhani informed him that two men brought a dispute to the Messenger of Allah, may Allah bless him and grant him peace. One of them said, "Messenger of Allah! Judge between us by the Book of Allah!" The other said, and he was the wiser of the two, "Yes, Messenger of Allah. Judge between us by the Book of Allah and give me permission to speak." He said, "Speak." He said, "My son was hired by this person and he committed fornication with his wife. He told me that my son deserved stoning, and I ransomed him for one hundred sheep and a slave-girl. Then I asked the people of knowledge and they told me that my son deserved to be flogged with one hundred lashes and exiled for a year, and they informed me that the woman deserved to be stoned." The Messenger of Allah, may Allah bless him and grant him peace, said, "By him in whose Hand myself is, I will judge between you by the Book of Allah. As for your sheep and slave girl, they should be returned to you. Your son should have one hundred lashes and be exiled for a year." He ordered Unays al-Aslami to go to the wife of the other man and to stone her if she confessed . She confessed and he stoned her}}
\hadithdefcmd{malik}{1506}{حَدَّثَنِي مَالِكٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرَأَيْتَ لَوْ أَنِّي وَجَدْتُ مَعَ امْرَأَتِي رَجُلاً أَأُمْهِلُهُ حَتَّى آتِيَ بِأَرْبَعَةِ شُهَدَاءَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{1506}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Suhayl ibn Abi Salih from his father from Abu Hurayra that Sad ibn Ubada said to the Messenger of Allah, may Allah bless him and grant him peace, "What do you think I should do if I were to find a man with my wife? Should I leave him there until I had brought four witnesses?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Yes}}
\hadithdefcmd{malik}{1507}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ الرَّجْمُ فِي كِتَابِ اللَّهِ حَقٌّ عَلَى مَنْ زَنَى مِنَ الرِّجَالِ وَالنِّسَاءِ إِذَا أُحْصِنَ إِذَا قَامَتِ الْبَيِّنَةُ أَوْ كَانَ الْحَبَلُ أَوْ الاِعْتِرَافُ ‏.‏\hadithno{1507}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud that Abdullah ibn Abbas said, "I heard Umar ibn al- Khattab say, 'Stoning is in the Book of Allah for those who commit adultery, men or women when they are muhsan and when there is clear proof of pregnancy or a confession}}
\hadithdefcmd{malik}{1508}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَتَاهُ رَجُلٌ وَهُوَ بِالشَّامِ فَذَكَرَ لَهُ أَنَّهُ وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَبَعَثَ عُمَرُ بْنُ الْخَطَّابِ أَبَا وَاقِدٍ اللَّيْثِيَّ إِلَى امْرَأَتِهِ يَسْأَلُهَا عَنْ ذَلِكَ فَأَتَاهَا وَعِنْدَهَا نِسْوَةٌ حَوْلَهَا فَذَكَرَ لَهَا الَّذِي قَالَ زَوْجُهَا لِعُمَرَ بْنِ الْخَطَّابِ وَأَخْبَرَهَا أَنَّهَا لاَ تُؤْخَذُ بِقَوْلِهِ وَجَعَلَ يُلَقِّنُهَا أَشْبَاهَ ذَلِكَ لِتَنْزِعَ فَأَبَتْ أَنْ تَنْزِعَ وَتَمَّتْ عَلَى الاِعْتِرَافِ فَأَمَرَ بِهَا عُمَرُ فَرُجِمَتْ ‏.‏\hadithno{1508}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Yahya ibn Said from Sulayman ibn Yasar from Abu Waqid al-Laythi that a man came to Umar ibn al-Khattab while he was in ash-Sham . He mentioned to him that he had found a man with his wife Umar sent Abu Waqid al-Laythi to the wife to question her about that. He came to her while there were women around her and mentioned to her what her husband had mentioned to Umar ibn al- Khattab, and informed her that she would not be punished on his word and began to suggest to her by that, that she should retract. She refused to retract and held firm to confession. Umar gave the order and she was stoned}}
\hadithdefcmd{malik}{1509}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ سَمِعَهُ يَقُولُ لَمَّا صَدَرَ عُمَرُ بْنُ الْخَطَّابِ مِنْ مِنًى أَنَاخَ بِالأَبْطَحِ ثُمَّ كَوَّمَ كَوْمَةً بَطْحَاءَ ثُمَّ طَرَحَ عَلَيْهَا رِدَاءَهُ وَاسْتَلْقَى ثُمَّ مَدَّ يَدَيْهِ إِلَى السَّمَاءِ فَقَالَ اللَّهُمَّ كَبِرَتْ سِنِّي وَضَعُفَتْ قُوَّتِي وَانْتَشَرَتْ رَعِيَّتِي ‏.‏ فَاقْبِضْنِي إِلَيْكَ غَيْرَ مُضَيِّعٍ وَلاَ مُفَرِّطٍ ‏.‏ ثُمَّ قَدِمَ الْمَدِينَةَ فَخَطَبَ النَّاسَ فَقَالَ أَيُّهَا النَّاسُ قَدْ سُنَّتْ لَكُمُ السُّنَنُ وَفُرِضَتْ لَكُمُ الْفَرَائِضُ وَتُرِكْتُمْ عَلَى الْوَاضِحَةِ إِلاَّ أَنْ تَضِلُّوا بِالنَّاسِ يَمِينًا وَشِمَالاً وَضَرَبَ بِإِحْدَى يَدَيْهِ عَلَى الأُخْرَى ثُمَّ قَالَ إِيَّاكُمْ أَنْ تَهْلِكُوا عَنْ آيَةِ الرَّجْمِ أَنْ يَقُولَ قَائِلٌ لاَ نَجِدُ حَدَّيْنِ فِي كِتَابِ اللَّهِ فَقَدْ رَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ أَنْ يَقُولَ النَّاسُ زَادَ عُمَرُ بْنُ الْخَطَّابِ فِي كِتَابِ اللَّهِ تَعَالَى ‏.‏ لَكَتَبْتُهَا الشَّيْخُ وَالشَّيْخَةُ فَارْجُمُوهُمَا الْبَتَّةَ ‏.‏ فَإِنَّا قَدْ قَرَأْنَاهَا ‏.‏ قَالَ مَالِكٌ قَالَ يَحْيَى بْنُ سَعِيدٍ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ فَمَا انْسَلَخَ ذُو الْحِجَّةِ حَتَّى قُتِلَ عُمَرُ رَحِمَهُ اللَّهُ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ قَوْلُهُ الشَّيْخُ وَالشَّيْخَةُ يَعْنِي الثَّيِّبَ وَالثَّيِّبَةَ فَارْجُمُوهُمَا الْبَتَّةَ ‏.‏ حَدَّثَنِي مَالِكٌ أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الَّذِي يَعْمَلُ عَمَلَ قَوْمِ لُوطٍ فَقَالَ ابْنُ شِهَابٍ عَلَيْهِ الرَّجْمُ أَحْصَنَ أَوْ لَمْ يُحْصِنْ ‏.‏\hadithno{1509}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me that Yahya ibn Said heard Said ibn al- Musayyab say, "When Umar ibn al-Khattab came from Mina, he made his camel kneel at al-Abtah, and then he gathered a pile of small stones and cast his cloak over them and dropped to the ground. Then he raised his hands to the sky and said, 'O Allah! I have become old and my strength has weakened. My flock is scattered. Take me to You with nothing missed out and without having neglected anything.' Then he went to Madina and addressed the people. He said, 'People! Sunan have been laid down for you. Obligations have been placed upon you. You have been left with a clear way unless you lead people astray right and left.' He struck one of his hands on the other and then said, 'Take care lest you destroy the ayat of stoning so that one will say, "We do not find two hadds in the Book of Allah." The Messenger of Allah, may Allah bless him and grant him peace, stoned, so we have stoned. By He in Whose Hand my self is, had it not been that people would say that Umar ibn al-Khattab has added to the Book of Allah ta- ala, we would have written it, "The full-grown man and the full-grown woman, stone them absolutely." We have certainly recited that.'" Malik said, "Yahya ibn Said said Said ibn al-Musayyab said, 'Dhu'l-Hijja had not passed before Umar was murdered, may Allah have mercy on him.' " Yahya said that he had heard Malik say, "As for his words 'The full-grown man and the full-grown woman' he meant, 'The man and the woman who have been married, stone them absolutely}}
\hadithdefcmd{malik}{1510}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أُتِيَ بِامْرَأَةٍ قَدْ وَلَدَتْ فِي سِتَّةِ أَشْهُرٍ فَأَمَرَ بِهَا أَنْ تُرْجَمَ فَقَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ لَيْسَ ذَلِكَ عَلَيْهَا إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏وَحَمْلُهُ وَفِصَالُهُ ثَلاَثُونَ شَهْرًا‏\}‏ وَقَالَ ‏\{‏وَالْوَالِدَاتُ يُرْضِعْنَ أَوْلاَدَهُنَّ حَوْلَيْنِ كَامِلَيْنِ لِمَنْ أَرَادَ أَنْ يُتِمَّ الرَّضَاعَةَ‏\}‏ فَالْحَمْلُ يَكُونُ سِتَّةَ أَشْهُرٍ فَلاَ رَجْمَ عَلَيْهَا ‏.‏ فَبَعَثَ عُثْمَانُ بْنُ عَفَّانَ فِي أَثَرِهَا فَوَجَدَهَا قَدْ رُجِمَتْ ‏.‏\hadithno{1510}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me that he had heard that Uthman ibn Affan was brought a woman who had given birth after six months and he ordered her to be stoned. Ali ibn Abi Talib said to him, "She does not deserve that. Allah, the Blessed, the Exalted, says in His Book, 'Their carrying and weaning is thirty months,' (Sura 46 ayat 15) and he said, 'Mothers suckle their children for two full years for whoever wishes to complete the suckling.' (Sura 2 ayat 233) Pregnancy can then be six months, so she does not deserve to be stoned." Uthman ibn Affan sent for her and found that she had already been stoned. Malik related to me that he asked Ibn Shihab about someone who committed sodomy. Ibn Shihab said, "He is to be stoned, whether or not he is muhsan}}
\hadithdefcmd{malik}{1511}{حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَجُلاً، اعْتَرَفَ عَلَى نَفْسِهِ بِالزِّنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَعَا لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَوْطٍ فَأُتِيَ بِسَوْطٍ مَكْسُورٍ فَقَالَ ‏"‏ فَوْقَ هَذَا ‏"‏ ‏.‏ فَأُتِيَ بِسَوْطٍ جَدِيدٍ لَمْ تُقْطَعْ ثَمَرَتُهُ فَقَالَ ‏"‏ دُونَ هَذَا ‏"‏ ‏.‏ فَأُتِيَ بِسَوْطٍ قَدْ رُكِبَ بِهِ وَلاَنَ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجُلِدَ ثُمَّ قَالَ ‏"‏ أَيُّهَا النَّاسُ قَدْ آنَ لَكُمْ أَنْ تَنْتَهُوا عَنْ حُدُودِ اللَّهِ مَنْ أَصَابَ مِنْ هَذِهِ الْقَاذُورَاتِ شَيْئًا فَلْيَسْتَتِرْ بِسِتْرِ اللَّهِ فَإِنَّهُ مَنْ يُبْدِي لَنَا صَفْحَتَهُ نُقِمْ عَلَيْهِ كِتَابَ اللَّهِ ‏"‏ ‏.‏\hadithno{1511}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Zayd ibn Aslam that a man confessed to fornication in the time of the Messenger of Allah, may Allah bless him and grant him peace. The Messenger of Allah, may Allah bless him and grant him peace, called for a whip, and he was brought a broken whip. He said, "Above this," and he was brought a new whip whose knots had not been cut yet. He said, "Below this," and he was brought a whip which had been used and made flexible. The Messenger of Allah, may Allah bless him and grant him peace, gave the order and he was flogged. Then he said, "People! The time has come for you to observe the limits of Allah. Whoever has had any of these ugly things befall him should cover them up with the veil of Allah. Whoever reveals to us his wrong action, we perform what is in the Book of Allah against him}}
\hadithdefcmd{malik}{1512}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ صَفِيَّةَ بِنْتَ أَبِي عُبَيْدٍ، أَخْبَرَتْهُ أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ أُتِيَ بِرَجُلٍ قَدْ وَقَعَ عَلَى جَارِيَةٍ بِكْرٍ فَأَحْبَلَهَا ثُمَّ اعْتَرَفَ عَلَى نَفْسِهِ بِالزِّنَا وَلَمْ يَكُنْ أَحْصَنَ فَأَمَرَ بِهِ أَبُو بَكْرٍ فَجُلِدَ الْحَدَّ ثُمَّ نُفِيَ إِلَى فَدَكَ ‏.‏\hadithno{1512}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Nafi that Safiyya bint Abi Ubayd informed him that a man who had had intercourse with a virgin slave- girl and made her pregnant was brought to Abu Bakr as-Siddiq. He confessed to fornication, and he was not muhsan. Abu Bakr gave the order and he was flogged with the hadd punishment. Then he was banished to Fadak, (thirty miles from Madina). Malik spoke about a person who confessed to fornication and then retracted it and said, "I didn't do it. I said that for such-and-such a reason," and he mentioned the reason. Malik said, "That is accepted from him and the hadd is not imposed on him. That is because the hadd is what is for Allah, and it is only applied by one of two means, either by a clear proof which establishes guilt or by a confession which is persisted in so that the hadd is imposed. If someone persists in his confession, the hadd is imposed on him." Malik said, "I have not seen the people of knowledge exiling slaves who have committed adultery}}
\hadithdefcmd{malik}{1513}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصِنْ فَقَالَ ‏ "‏ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي أَبَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏.‏\hadithno{1513}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from Abu Hurayra and Zayd ibn Khalid al-Juhani that the Messenger of Allah, may Allah bless him and grant him peace, was asked about a slave-girl who committed fornication and was not muhsana. He said, "If she commits fornication, then flog her. If she commits fornication again, then flog her, and if she commits fornication again, then sell her, if only for a rope." Ibn Shihab added, "I don't know whether it was three or four times}}
\hadithdefcmd{malik}{1514}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدًا، كَانَ يَقُومُ عَلَى رَقِيقِ الْخُمُسِ وَأَنَّهُ اسْتَكْرَهَ جَارِيَةً مِنْ ذَلِكَ الرَّقِيقِ فَوَقَعَ بِهَا فَجَلَدَهُ عُمَرُ بْنُ الْخَطَّابِ وَنَفَاهُ وَلَمْ يَجْلِدِ الْوَلِيدَةَ لأَنَّهُ اسْتَكْرَهَهَا ‏.‏\hadithno{1514}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Nafi that a slave was in charge of the slaves in the khumus and he forced a slave-girl among those slaves against her will and had intercourse with her. Umar ibn al-Khattab had him flogged and banished him, and he did not flog the slave-girl because the slave had forced her}}
\hadithdefcmd{malik}{1515}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ سُلَيْمَانَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ الْمَخْزُومِيَّ قَالَ أَمَرَنِي عُمَرُ بْنُ الْخَطَّابِ فِي فِتْيَةٍ مِنْ قُرَيْشٍ فَجَلَدْنَا وَلاَئِدَ مِنْ وَلاَئِدِ الإِمَارَةِ خَمْسِينَ خَمْسِينَ فِي الزِّنَا ‏.‏\hadithno{1515}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Yahya ibn Said that Sulayman ibn Yasar informed him that Abdullah ibn Abbas ibn Abi Rabia al-Makhzumi said, "Umar ibn al-Khattab gave me orders about the slaves of Quraysh and we flogged some of the slave-girls of the muslim lands fifty times each for fornication}}
\hadithdefcmd{malik}{1516}{حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، أَنَّهُ قَالَ جَلَدَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ عَبْدًا فِي فِرْيَةٍ ثَمَانِينَ ‏.‏ قَالَ أَبُو الزِّنَادِ فَسَأَلْتُ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ عَنْ ذَلِكَ فَقَالَ أَدْرَكْتُ عُمَرَ بْنَ الْخَطَّابِ وَعُثْمَانَ بْنَ عَفَّانَ وَالْخُلَفَاءَ هَلُمَّ جَرًّا فَمَا رَأَيْتُ أَحَدًا جَلَدَ عَبْدًا فِي فِرْيَةٍ أَكْثَرَ مِنْ أَرْبَعِينَ ‏.‏\hadithno{1516}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik said, "The position with us about a woman who is found to be pregnant and has no husband and she says, 'I was forced,' or she says, 'I was married,' is that it is not accepted from her and the hadd is inflicted on her unless she has a clear proof of what she claims about the marriage or that she was forced or she comes bleeding if she was a virgin or she calls out for help so that someone comes to her and she is in that state or what resembles it of the situation in which the violation occurred." He said, "If she does not produce any of those, the hadd is inflicted on her and what she claims of that is not accepted from her." Malik said, "A raped woman cannot marry until she has restored herself by three menstrual periods." He said, "If she doubts her periods, she does not marry until she has freed herself of that doubt." Malik related to me from Abu'z-Zinad that he said, ''Umar ibn Abd al-Aziz flogged a slave with eighty lashes for slander." Abu'z-Zinad said, "I asked Abdullah ibn Amir ibn Rabia about that. He said, 'I saw Umar ibn al-Khattab, Uthman ibn Affan, the Khalifs, and so on, and I did not see any of them flog a slave more than forty lashes for slander}}
\hadithdefcmd{malik}{1517}{حَدَّثَنِي مَالِكٌ، عَنْ زُرَيْقِ بْنِ حَكِيمٍ الأَيْلِيِّ، أَنَّ رَجُلاً، يُقَالُ لَهُ مِصْبَاحٌ اسْتَعَانَ ابْنًا لَهُ فَكَأَنَّهُ اسْتَبْطَأَهُ فَلَمَّا جَاءَهُ قَالَ لَهُ يَا زَانٍ ‏.‏ قَالَ زُرَيْقٌ فَاسْتَعْدَانِي عَلَيْهِ فَلَمَّا أَرَدْتُ أَنْ أَجْلِدَهُ قَالَ ابْنُهُ وَاللَّهِ لَئِنْ جَلَدْتَهُ لأَبُوأَنَّ عَلَى نَفْسِي بِالزِّنَا ‏.‏ فَلَمَّا قَالَ ذَلِكَ أَشْكَلَ عَلَىَّ أَمْرُهُ فَكَتَبْتُ فِيهِ إِلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ - وَهُوَ الْوَالِي يَوْمَئِذٍ - أَذْكُرُ لَهُ ذَلِكَ فَكَتَبَ إِلَىَّ عُمَرُ أَنْ أَجِزْ عَفْوَهُ ‏.‏ قَالَ زُرَيْقٌ وَكَتَبْتُ إِلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ أَيْضًا أَرَأَيْتَ رَجُلاً افْتُرِيَ عَلَيْهِ أَوْ عَلَى أَبَوَيْهِ وَقَدْ هَلَكَا أَوْ أَحَدُهُمَا ‏.‏ قَالَ فَكَتَبَ إِلَىَّ عُمَرُ إِنْ عَفَا فَأَجِزْ عَفْوَهُ فِي نَفْسِهِ وَإِنِ افْتُرِيَ عَلَى أَبَوَيْهِ وَقَدْ هَلَكَا أَوْ أَحَدُهُمَا فَخُذْ لَهُ بِكِتَابِ اللَّهِ إِلاَّ أَنْ يُرِيدَ سِتْرًا ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ وَذَلِكَ أَنْ يَكُونَ الرَّجُلُ الْمُفْتَرَى عَلَيْهِ يَخَافُ إِنْ كُشِفَ ذَلِكَ مِنْهُ أَنْ تَقُومَ عَلَيْهِ بَيِّنَةٌ فَإِذَا كَانَ عَلَى مَا وَصَفْتُ فَعَفَا جَازَ عَفْوُهُ ‏.‏\hadithno{1517}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Zurayq ibn Hakim al-Ayli that a man called Misbah asked his son for help and he thought him unnecessarily slow. When the son came, his father said to him, "O fornicator." Zurayq said, "So the son asked me to help him against the father. When I wanted to flog him, his son said, 'By Allah, if you flog him, I will acknowledge that I have committed fornication.' When he said that, the situation was confused for me, so I wrote about it to Umar ibn Abd al- Aziz who was the governor at that time, and I mentioned it to him. Umar wrote me to permit his pardon." Zurayq said, "I wrote to Umar ibn Abd al-Aziz also, 'What do you think about a man who is slandered or his parents are slandered and both or only one of them are dead?' He said, Umar wrote to me, 'If he forgives, his pardon is permitted for himself. If his parents are slandered and one or both of them are dead, take the judgement of the Book of Allah for it unless he wants to veil it.' " Yahya said, "I heard Malik say, 'That is because the slandered man might fear that if that is unveiled about him, a clear proof might be established. If it is according to what we have described, his pardon is permitted}}
\hadithdefcmd{malik}{1518}{حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ فِي رَجُلٍ قَذَفَ قَوْمًا جَمَاعَةً أَنَّهُ لَيْسَ عَلَيْهِ إِلاَّ حَدٌّ وَاحِدٌ ‏.‏ قَالَ مَالِكٌ وَإِنْ تَفَرَّقُوا فَلَيْسَ عَلَيْهِ إِلاَّ حَدٌّ وَاحِدٌ ‏.‏ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الرِّجَالِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَارِثَةَ بْنِ النُّعْمَانِ الأَنْصَارِيِّ ثُمَّ مِنْ بَنِي النَّجَّارِ عَنْ أُمِّهِ، عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ أَنَّ رَجُلَيْنِ، اسْتَبَّا فِي زَمَانِ عُمَرَ بْنِ الْخَطَّابِ فَقَالَ أَحَدُهُمَا لِلآخَرِ وَاللَّهِ مَا أَبِي بِزَانٍ وَلاَ أُمِّي بِزَانِيَةٍ ‏.‏ فَاسْتَشَارَ فِي ذَلِكَ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ قَائِلٌ مَدَحَ أَبَاهُ وَأُمَّهُ وَقَالَ آخَرُونَ قَدْ كَانَ لأَبِيهِ وَأُمِّهِ مَدْحٌ غَيْرُ هَذَا نَرَى أَنْ تَجْلِدَهُ الْحَدَّ ‏.‏ فَجَلَدَهُ عُمَرُ الْحَدَّ ثَمَانِينَ ‏.‏ قَالَ مَالِكٌ لاَ حَدَّ عِنْدَنَا إِلاَّ فِي نَفْىٍ أَوْ قَذْفٍ أَوْ تَعْرِيضٍ يُرَى أَنَّ قَائِلَهُ إِنَّمَا أَرَادَ بِذَلِكَ نَفْيًا أَوْ قَذْفًا فَعَلَى مَنْ قَالَ ذَلِكَ الْحَدُّ تَامًّا ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّهُ إِذَا نَفَى رَجُلٌ رَجُلاً مِنْ أَبِيهِ فَإِنَّ عَلَيْهِ الْحَدَّ وَإِنْ كَانَتْ أُمُّ الَّذِي نُفِيَ مَمْلُوكَةً فَإِنَّ عَلَيْهِ الْحَدَّ ‏.‏\hadithno{1518}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa that his father said that there was only one hadd against a man who slandered a group of people. Malik said, "If they are on separate occasions there is still only one hadd against him." Malik related to me from Abu'r-Rijal Muhammad ibn Abd ar-Rahman ibn Haritha ibn an-Numan al- Ansari, then from the Banu'n-Najar from his mother Amra bint Abd ar- Rahman that two men cursed each other in the time of Umar ibn al- Khattab. One of them said to the other, " By Allah, my father is not an adulterer and my mother is not an adulteress." Umar ibn al-Khattab asked advice about that. One person said, "He has praised his father and mother." Another said, "His father and mother have praise other than this. We think that he is to be flogged with the hadd." So Umar flogged him with the hadd of eighty lashes. Malik said, "There is no hadd in our view except for slander, denial or insinuation, in which one sees that the speaker intends by that denial or slander. Then the hadd is completely imposed on the one who said it." Malik said, "What is done in our community when a man denies that another man is from his father, is that he deserves the hadd. If the mother who is denied is a slave, then he deserves the hadd as well}}
\hadithdefcmd{malik}{1520}{حَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لِرَجُلٍ خَرَجَ بِجَارِيَةٍ لاِمْرَأَتِهِ مَعَهُ فِي سَفَرٍ فَأَصَابَهَا فَغَارَتِ امْرَأَتُهُ ‏.‏ فَذَكَرَتْ ذَلِكَ لِعُمَرَ بْنِ الْخَطَّابِ فَسَأَلَهُ عَنْ ذَلِكَ فَقَالَ وَهَبَتْهَا لِي ‏.‏ فَقَالَ عُمَرُ لَتَأْتِينِي بِالْبَيِّنَةِ أَوْ لأَرْمِيَنَّكَ بِالْحِجَارَةِ ‏.‏ قَالَ فَاعْتَرَفَتِ امْرَأَتُهُ أَنَّهَا وَهَبَتْهَا لَهُ ‏.‏\hadithno{1520}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik said, "The best of what is heard about a slave-girl whom a man has intercourse with while he has a partner in her is that the hadd is not inflicted on him and the child is connected to him. When the slave-girl becomes pregnant, her value is estimated and he gives his partners their shares of the price and the slave-girl is his. That is what is done among us." Malik said about a man who made his slave-girl halal to a man that if the one for whom she was made halal had intercourse with her, her value was estimated on the day he had intercourse with her and he owed that to her owner whether or not she conceived. The hadd was averted from him by that. If she conceived the child was connected to him. Malik said about a man who had intercourse with his son's or daughter's slave-girl, "The hadd is averted from him and he owes the estimated value of the slave-girl whether or not she conceives." Malik related to me from Rabia ibn Abi Abd ar-Rahman that Umar ibn al-Khattab spoke about a man who went out with his wife's slave- girl on a journey and had intercourse with her and then the wife became jealous and mentioned that to Umar ibn al-Khattab. Umar questioned him about it. He said, "She gave her to me." Umar said, "Bring me a clear proof or I will stone you." Rabia added, "The wife confessed that she had given her to him}}
\hadithdefcmd{malik}{1521}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{1521}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, cut off the hand of a man who stole a shield whose price was three dirhams}}
\hadithdefcmd{malik}{1522}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ الْمَكِّيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ مُعَلَّقٍ وَلاَ فِي حَرِيسَةِ جَبَلٍ ‏"‏ فَإِذَا آوَاهُ الْمُرَاحُ أَوِ الْجَرِينُ فَالْقَطْعُ فِيمَا يَبْلُغُ ثَمَنَ الْمِجَنِّ ‏.‏\hadithno{1522}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abd ar-Rahman abu Husayn al-Makki that the Messenger of Allah, may Allah bless him and grant him peace, said, "The hand is not cut off for fruit hanging on the tree and for sheep kept in the mountains. So when they are taken from the fold or the place where the fruit is dried, a hand is cut off for whatever reaches the price of a shield}}
\hadithdefcmd{malik}{1523}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ سَارِقًا، سَرَقَ فِي زَمَانِ عُثْمَانَ أُتْرُجَّةً فَأَمَرَ بِهَا عُثْمَانُ بْنُ عَفَّانَ أَنْ تُقَوَّمَ فَقُوِّمَتْ بِثَلاَثَةِ دَرَاهِمَ مِنْ صَرْفِ اثْنَىْ عَشَرَ دِرْهَمًا بِدِينَارٍ فَقَطَعَ عُثْمَانُ يَدَهُ ‏.‏\hadithno{1523}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from his father from Amra bint Abd ar-Rahman that a thief stole a citron in the time of Uthman Uthman ibn Affan ordered its value to be estimated and it was estimated at three dirhams at the rate of exchange of twelve dirhams for the dinar, so Uthman cut off his hand}}
\hadithdefcmd{malik}{1524}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا طَالَ عَلَىَّ وَمَا نَسِيتُ ‏ "‏ الْقَطْعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{1524}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Amra bint Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "It has not been a long time for me and I have not forgotten. A thief's hand is cut off for a quarter of a dinar and upwards}}
\hadithdefcmd{malik}{1525}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا قَالَتْ خَرَجَتْ عَائِشَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم إِلَى مَكَّةَ وَمَعَهَا مَوْلاَتَانِ لَهَا وَمَعَهَا غُلاَمٌ لِبَنِي عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ فَبَعَثَتْ مَعَ الْمَوْلاَتَيْنِ بِبُرْدٍ مُرَجَّلٍ قَدْ خِيطَ عَلَيْهِ خِرْقَةٌ خَضْرَاءُ قَالَتْ فَأَخَذَ الْغُلاَمُ الْبُرْدَ فَفَتَقَ عَنْهُ فَاسْتَخْرَجَهُ وَجَعَلَ مَكَانَهُ لِبْدًا أَوْ فَرْوَةً وَخَاطَ عَلَيْهِ فَلَمَّا قَدِمَتِ الْمَوْلاَتَانِ الْمَدِينَةَ دَفَعَتَا ذَلِكَ إِلَى أَهْلِهِ فَلَمَّا فَتَقُوا عَنْهُ وَجَدُوا فِيهِ اللِّبْدَ وَلَمْ يَجِدُوا الْبُرْدَ فَكَلَّمُوا الْمَرْأَتَيْنِ فَكَلَّمَتَا عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَوْ كَتَبَتَا إِلَيْهَا وَاتَّهَمَتَا الْعَبْدَ فَسُئِلَ الْعَبْدُ عَنْ ذَلِكَ فَاعْتَرَفَ فَأَمَرَتْ بِهِ عَائِشَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم فَقُطِعَتْ يَدُهُ وَقَالَتْ عَائِشَةُ الْقَطْعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{1525}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Hazim that Amra bint Abd ar-Rahman said, "A'isha, the wife of the Prophet, may Allah bless him and grant him peace, went out to Makka and she had two girl mawlas of hers and a slave belonging to the sons of Abdullah ibn Abi Bakr as-Siddiq . She sent a figured cloak with the two mawlas which was sewn up in a piece of green cloth." Amra continued, "The slave took it and unstitched it and took out the cloak. In its place, he put some felt or skin and sewed it up again. When the mawla girls came to Madina, they gave it to his people. When they opened it, they found felt in it and did not find the cloak. They spoke to the two women and they spoke to A'isha, the wife of the Prophet, may Allah bless him and grant him peace, or they wrote to her and suspected the slave. The slave was asked about it and confessed. A'isha, the wife of the Prophet, may Allah bless him and grant him peace, gave the order and his hand was cut off. A'isha said, 'A thief's hand is cut off for a quarter of a dinar and upwards.' " Malik said, "The limit I prefer above which cutting off the hand is obliged is three dirhams, whether the exchange is high or low. That is because the Messenger of Allah, may Allah bless him and grant him peace, cut off the hand of a thief for a shield whose value was three dirhams, and Uthman ibn Affan cut off the hand of a thief for a citron which was estimated at three dirhams. This is what I prefer of what I have heard on the matter}}
\hadithdefcmd{malik}{1526}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدًا، لِعَبْدِ اللَّهِ بْنِ عُمَرَ سَرَقَ وَهُوَ آبِقٌ فَأَرْسَلَ بِهِ عَبْدُ اللَّهِ بْنُ عُمَرَ إِلَى سَعِيدِ بْنِ الْعَاصِ - وَهُوَ أَمِيرُ الْمَدِينَةِ - لِيَقْطَعَ يَدَهُ فَأَبَى سَعِيدٌ أَنْ يَقْطَعَ يَدَهُ وَقَالَ لاَ تُقْطَعُ يَدُ الآبِقِ السَّارِقِ إِذَا سَرَقَ ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ فِي أَىِّ كِتَابِ اللَّهِ وَجَدْتَ هَذَا ثُمَّ أَمَرَ بِهِ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقُطِعَتْ يَدُهُ ‏.‏\hadithno{1526}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that a slave of Abdullah ibn Umar stole while he was a runaway. Abdullah ibn Umar sent him to Said ibn al-As, who was the amir of Madina, to cut off his hand. Said refused to cut off his hand. He said, "The hand of a runaway slave is not cut off when he steals." Abdullah ibn Umar said to him, "In what Book of Allah did you find this?" Then Abdullah ibn Umar gave the order, and his hand was cut off}}
\hadithdefcmd{malik}{1527}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زُرَيْقِ بْنِ حَكِيمٍ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، أَخَذَ عَبْدًا آبِقًا قَدْ سَرَقَ قَالَ فَأَشْكَلَ عَلَىَّ أَمْرُهُ - قَالَ - فَكَتَبْتُ فِيهِ إِلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ أَسْأَلُهُ عَنْ ذَلِكَ وَهُوَ الْوَالِي يَوْمَئِذٍ - قَالَ - فَأَخْبَرْتُهُ أَنَّنِي كُنْتُ أَسْمَعُ أَنَّ الْعَبْدَ الآبِقَ إِذَا سَرَقَ وَهُوَ آبِقٌ لَمْ تُقْطَعْ يَدُهُ - قَالَ - فَكَتَبَ إِلَىَّ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ نَقِيضَ كِتَابِي يَقُولُ كَتَبْتَ إِلَىَّ أَنَّكَ كُنْتَ تَسْمَعُ أَنَّ الْعَبْدَ الآبِقَ إِذَا سَرَقَ لَمْ تُقْطَعْ يَدُهُ وَأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏وَالسَّارِقُ وَالسَّارِقَةُ فَاقْطَعُوا أَيْدِيَهُمَا جَزَاءً بِمَا كَسَبَا نَكَالاً مِنَ اللَّهِ وَاللَّهُ عَزِيزٌ حَكِيمٌ‏\}‏ ‏.‏ فَإِنْ بَلَغَتْ سَرِقَتُهُ رُبُعَ دِينَارٍ فَصَاعِدًا فَاقْطَعْ يَدَهُ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، وَعُرْوَةَ بْنَ الزُّبَيْرِ، كَانُوا يَقُولُونَ إِذَا سَرَقَ الْعَبْدُ الآبِقُ مَا يَجِبُ فِيهِ الْقَطْعُ قُطِعَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا أَنَّ الْعَبْدَ الآبِقَ إِذَا سَرَقَ مَا يَجِبُ فِيهِ الْقَطْعُ قُطِعَ ‏.‏\hadithno{1527}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Zurayq ibn Hakim informed him that he had a runaway slave who had stolen. He said, "The situation was obscure for me, so I wrote to Umar ibn Abd al-Aziz to ask him about it. He was the governor at that time. I informed him that I had heard that if a runaway slave stole while he was a fugitive, his hand was not cut off. 'Umar ibn Abd al-Aziz wrote to contradict my letter, 'You wrote to me that you have heard that when the runaway slave steals, his hand is not cut off. Allah, the Blessed, the Exalted, says in His Book, 'The thief, male and female, cut off the hands of both, as a recompense for what they have earned, and an exemplary punishment from Allah. Allah is Mighty, Wise.' (Sura 5 ayat 41) When his theft reaches a quarter of a dinar, and upwards, his hand is cut off.' " Yahya related to me from Malik that he had heard that al- Qasim ibn Muhammad and Salim ibn Abdullah and Urwa ibn az-Zubayr said, "When a runaway slave steals something for which cutting off the hand is obliged, his hand is cut off." Malik said, "The way of doing things amongst us about which there is no dispute is that when the runaway slave steals that for which cutting off the hand is obliged, his hand is cut off}}
\hadithdefcmd{malik}{1529}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، أَنَّ صَفْوَانَ بْنَ أُمَيَّةَ، قِيلَ لَهُ إِنَّهُ مَنْ لَمْ يُهَاجِرْ هَلَكَ ‏.‏ فَقَدِمَ صَفْوَانُ بْنُ أُمَيَّةَ الْمَدِينَةَ فَنَامَ فِي الْمَسْجِدِ وَتَوَسَّدَ رِدَاءَهُ فَجَاءَ سَارِقٌ فَأَخَذَ رِدَاءَهُ فَأَخَذَ صَفْوَانُ السَّارِقَ فَجَاءَ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَسَرَقْتَ رِدَاءَ هَذَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُقْطَعَ يَدُهُ فَقَالَ لَهُ صَفْوَانُ إِنِّي لَمْ أُرِدْ هَذَا يَا رَسُولَ اللَّهِ هُوَ عَلَيْهِ صَدَقَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلاَّ قَبْلَ أَنْ تَأْتِيَنِي بِهِ ‏"‏ ‏.‏\hadithno{1529}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Safwan ibn Abdullah ibn Safwan that it was said to Safwan ibn Umayya, "Whoever does not do hijra is ruined." So Safwan ibn Umayya went to Madina and slept in the mosque with his cloak as a pillow. A thief came and took his cloak and Safwan grabbed hold of the thief and brought him to the Messenger of Allah, may Allah bless him and grant him peace. The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Did you steal this cloak?" He said, "Yes." So the Messenger of Allah, may Allah bless him and grant him peace, ordered that his hand be cut off. Safwan said to him, "I did not intend this. It is his as sadaqa." The Messenger of Allah, may Allah bless him and grant him peace, said, "Why didn't you do it before bringing him to me?}}
\hadithdefcmd{malik}{1530}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ الزُّبَيْرَ بْنَ الْعَوَّامِ، لَقِيَ رَجُلاً قَدْ أَخَذَ سَارِقًا وَهُوَ يُرِيدُ أَنْ يَذْهَبَ بِهِ إِلَى السُّلْطَانِ فَشَفَعَ لَهُ الزُّبَيْرُ لِيُرْسِلَهُ فَقَالَ لاَ حَتَّى أَبْلُغَ بِهِ السُّلْطَانَ ‏.‏ فَقَالَ الزُّبَيْرُ إِذَا بَلَغْتَ بِهِ السُّلْطَانَ فَلَعَنَ اللَّهُ الشَّافِعَ وَالْمُشَفِّعَ ‏.‏\hadithno{1530}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that az-Zubayr ibn al-Awwam came across a man who had taken hold of a thief and was intending to take him to the Sultan. Az-Zubayr ibn al- Awwam interceded for him to let him go. He said, "No. Not until I take him to the Sultan." Az-Zubayr said, "When you reach the Sultan with him, Allah curses the one who intercedes and the one who accepts the intercession}}
\hadithdefcmd{malik}{1531}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، مِنْ أَهْلِ الْيَمَنِ أَقْطَعَ الْيَدِ وَالرِّجْلِ قَدِمَ فَنَزَلَ عَلَى أَبِي بَكْرٍ الصِّدِّيقِ فَشَكَا إِلَيْهِ أَنَّ عَامِلَ الْيَمَنِ قَدْ ظَلَمَهُ فَكَانَ يُصَلِّي مِنَ اللَّيْلِ فَيَقُولُ أَبُو بَكْرٍ وَأَبِيكَ مَا لَيْلُكَ بِلَيْلِ سَارِقٍ ‏.‏ ثُمَّ إِنَّهُمْ فَقَدُوا عِقْدًا لأَسْمَاءَ بِنْتِ عُمَيْسٍ امْرَأَةِ أَبِي بَكْرٍ الصِّدِّيقِ فَجَعَلَ الرَّجُلُ يَطُوفُ مَعَهُمْ وَيَقُولُ اللَّهُمَّ عَلَيْكَ بِمَنْ بَيَّتَ أَهْلَ هَذَا الْبَيْتِ الصَّالِحِ ‏.‏ فَوَجَدُوا الْحُلِيَّ عِنْدَ صَائِغٍ زَعَمَ أَنَّ الأَقْطَعَ جَاءَهُ بِهِ فَاعْتَرَفَ بِهِ الأَقْطَعُ أَوْ شُهِدَ عَلَيْهِ بِهِ فَأَمَرَ بِهِ أَبُو بَكْرٍ الصِّدِّيقُ فَقُطِعَتْ يَدُهُ الْيُسْرَى وَقَالَ أَبُو بَكْرٍ وَاللَّهِ لَدُعَاؤُهُ عَلَى نَفْسِهِ أَشَدُّ عِنْدِي عَلَيْهِ مِنْ سَرِقَتِهِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي الَّذِي يَسْرِقُ مِرَارًا ثُمَّ يُسْتَعْدَى عَلَيْهِ إِنَّهُ لَيْسَ عَلَيْهِ إِلاَّ أَنْ تُقْطَعَ يَدُهُ لِجَمِيعِ مَنْ سَرَقَ مِنْهُ إِذَا لَمْ يَكُنْ أُقِيمَ عَلَيْهِ الْحَدُّ فَإِنْ كَانَ قَدْ أُقِيمَ عَلَيْهِ الْحَدُّ قَبْلَ ذَلِكَ ثُمَّ سَرَقَ مَا يَجِبُ فِيهِ الْقَطْعُ قُطِعَ أَيْضًا ‏.‏\hadithno{1531}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that a man from Yemen who had his hand and foot cut off came and went before Abu Bakr as-Siddiq and complained to him that the governor of the Yemen had wronged him, and the man used to pray part of the night. Abu Bakr said, "By your father, your night is not the night of a thief." Then they missed a necklace of Asma bint Umays, the wife of Abu Bakr as-Siddiq. The man came to go around with them looking for it. He said, "O Allah! You are responsible for the one who invaded the people of this good house by night!" They found the jewelry with a goldsmith. He claimed that the maimed man had brought it to him. The maimed man confessed or it was testified against him. Abu Bakr as-Siddiq ordered that his left hand be cut off. Abu Bakr said, "By Allah! His dua against himself is more serious, as far as I am concerned, than his theft." Yahya said that Malik said, "What is done among us about the person who steals several times and is then called to reckoning, is that only his hand is cut off for all he stole when the hadd has not been applied againsthim. If the hadd has been applied against him before that, and he steals what obliges cutting off, then the next limb is cut off}}
\hadithdefcmd{malik}{1532}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّ أَبَا الزِّنَادِ، أَخْبَرَهُ أَنَّ عَامِلاً لِعُمَرَ بْنِ عَبْدِ الْعَزِيزِ أَخَذَ نَاسًا فِي حِرَابَةٍ وَلَمْ يَقْتُلُوا أَحَدًا فَأَرَادَ أَنْ يَقْطَعَ أَيْدِيَهُمْ أَوْ يَقْتُلَ فَكَتَبَ إِلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ فِي ذَلِكَ فَكَتَبَ إِلَيْهِ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ لَوْ أَخَذْتَ بِأَيْسَرِ ذَلِكَ ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ الأَمْرُ عِنْدَنَا فِي الَّذِي يَسْرِقُ أَمْتِعَةَ النَّاسِ الَّتِي تَكُونُ مَوْضُوعَةً بِالأَسْوَاقِ مُحْرَزَةً قَدْ أَحْرَزَهَا أَهْلُهَا فِي أَوْعِيَتِهِمْ وَضَمُّوا بَعْضَهَا إِلَى بَعْضٍ إِنَّهُ مَنْ سَرَقَ مِنْ ذَلِكَ شَيْئًا مِنْ حِرْزِهِ فَبَلَغَ قِيمَتُهُ مَا يَجِبُ فِيهِ الْقَطْعُ فَإِنَّ عَلَيْهِ الْقَطْعَ كَانَ صَاحِبُ الْمَتَاعِ عِنْدَ مَتَاعِهِ أَوْ لَمْ يَكُنْ لَيْلاً ذَلِكَ أَوْ نَهَارًا ‏.‏ قَالَ مَالِكٌ فِي الَّذِي يَسْرِقُ مَا يَجِبُ عَلَيْهِ فِيهِ الْقَطْعُ ثُمَّ يُوجَدُ مَعَهُ مَا سَرَقَ فَيُرَدُّ إِلَى صَاحِبِهِ إِنَّهُ تُقْطَعُ يَدُهُ ‏.‏ قَالَ مَالِكٌ فَإِنْ قَالَ قَائِلٌ كَيْفَ تُقْطَعُ يَدُهُ وَقَدْ أُخِذَ الْمَتَاعُ مِنْهُ وَدُفِعَ إِلَى صَاحِبِهِ فَإِنَّمَا هُوَ بِمَنْزِلَةِ الشَّارِبِ يُوجَدُ مِنْهُ رِيحُ الشَّرَابِ الْمُسْكِرِ وَلَيْسَ بِهِ سُكْرٌ فَيُجْلَدُ الْحَدَّ ‏.‏ قَالَ وَإِنَّمَا يُجْلَدُ الْحَدَّ فِي الْمُسْكِرِ إِذَا شَرِبَهُ وَإِنْ لَمْ يُسْكِرْهُ وَذَلِكَ أَنَّهُ إِنَّمَا شَرِبَهُ لِيُسْكِرَهُ فَكَذَلِكَ تُقْطَعُ يَدُ السَّارِقِ فِي السَّرِقَةِ الَّتِي أُخِذَتْ مِنْهُ وَلَوْ لَمْ يَنْتَفِعْ بِهَا وَرَجَعَتْ إِلَى صَاحِبِهَا وَإِنَّمَا سَرَقَهَا حِينَ سَرَقَهَا لِيَذْهَبَ بِهَا ‏.‏ قَالَ مَالِكٌ فِي الْقَوْمِ يَأْتُونَ إِلَى الْبَيْتِ فَيَسْرِقُونَ مِنْهُ جَمِيعًا فَيَخْرُجُونَ بِالْعِدْلِ يَحْمِلُونَهُ جَمِيعًا أَوِ الصُّنْدُوقِ أَوِ الْخَشَبَةِ أَوْ بِالْمِكْتَلِ أَوْ مَا أَشْبَهَ ذَلِكَ مِمَّا يَحْمِلُهُ الْقَوْمُ جَمِيعًا إِنَّهُمْ إِذَا أَخْرَجُوا ذَلِكَ مِنْ حِرْزِهِ وَهُمْ يَحْمِلُونَهُ جَمِيعًا فَبَلَغَ ثَمَنُ مَا خَرَجُوا بِهِ مِنْ ذَلِكَ مَا يَجِبُ فِيهِ الْقَطْعُ - وَذَلِكَ ثَلاَثَةُ دَرَاهِمَ فَصَاعِدًا - فَعَلَيْهِمُ الْقَطْعُ جَمِيعًا ‏.‏ قَالَ وَإِنْ خَرَجَ كُلُّ وَاحِدٍ مِنْهُمْ بِمَتَاعٍ عَلَى حِدَتِهِ فَمَنْ خَرَجَ مِنْهُمْ بِمَا تَبْلُغُ قِيمَتُهُ ثَلاَثَةَ دَرَاهِمَ فَصَاعِدًا فَعَلَيْهِ الْقَطْعُ وَمَنْ لَمْ يَخْرُجْ مِنْهُمْ بِمَا تَبْلُغُ قِيمَتُهُ ثَلاَثَةَ دَرَاهِمَ فَلاَ قَطْعَ عَلَيْهِ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا أَنَّهُ إِذَا كَانَتْ دَارُ رَجُلٍ مُغْلَقَةً عَلَيْهِ لَيْسَ مَعَهُ فِيهَا غَيْرُهُ فَإِنَّهُ لاَ يَجِبُ عَلَى مَنْ سَرَقَ مِنْهَا شَيْئًا الْقَطْعُ حَتَّى يَخْرُجَ بِهِ مِنَ الدَّارِ كُلِّهَا وَذَلِكَ أَنَّ الدَّارَ كُلَّهَا هِيَ حِرْزُهُ فَإِنْ كَانَ مَعَهُ فِي الدَّارِ سَاكِنٌ غَيْرُهُ وَكَانَ كُلُّ إِنْسَانٍ مِنْهُمْ يُغْلِقُ عَلَيْهِ بَابَهُ وَكَانَتْ حِرْزًا لَهُمْ جَمِيعًا فَمَنْ سَرَقَ مِنْ بُيُوتِ تِلْكَ الدَّارِ شَيْئًا يَجِبُ فِيهِ الْقَطْعُ فَخَرَجَ بِهِ إِلَى الدَّارِ فَقَدْ أَخْرَجَهُ مِنْ حِرْزِهِ إِلَى غَيْرِ حِرْزِهِ وَوَجَبَ عَلَيْهِ فِيهِ الْقَطْعُ ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا فِي الْعَبْدِ يَسْرِقُ مِنْ مَتَاعِ سَيِّدِهِ أَنَّهُ إِنْ كَانَ لَيْسَ مِنْ خَدَمِهِ وَلاَ مِمَّنْ يَأْمَنُ عَلَى بَيْتِهِ ثُمَّ دَخَلَ سِرًّا فَسَرَقَ مِنْ مَتَاعِ سَيِّدِهِ مَا يَجِبُ فِيهِ الْقَطْعُ فَلاَ قَطْعَ عَلَيْهِ وَكَذَلِكَ الأَمَةُ إِذَا سَرَقَتْ مِنْ مَتَاعِ سَيِّدِهَا لاَ قَطْعَ عَلَيْهَا ‏.‏ وَقَالَ فِي الْعَبْدِ لاَ يَكُونُ مِنْ خَدَمِهِ وَلاَ مِمَّنْ يَأْمَنُ عَلَى بَيْتِهِ فَدَخَلَ سِرًّا فَسَرَقَ مِنْ مَتَاعِ امْرَأَةِ سَيِّدِهِ مَا يَجِبُ فِيهِ الْقَطْعُ إِنَّهُ تُقْطَعُ يَدُهُ ‏.‏ قَالَ وَكَذَلِكَ أَمَةُ الْمَرْأَةِ إِذَا كَانَتْ لَيْسَتْ بِخَادِمٍ لَهَا وَلاَ لِزَوْجِهَا وَلاَ مِمَّنْ تَأْمَنُ عَلَى بَيْتِهَا فَدَخَلَتْ سِرًّا فَسَرَقَتْ مِنْ مَتَاعِ سَيِّدَتِهَا مَا يَجِبُ فِيهِ الْقَطْعُ فَلاَ قَطْعَ عَلَيْهَا ‏.‏ قَالَ مَالِكٌ وَكَذَلِكَ أَمَةُ الْمَرْأَةِ الَّتِي لاَ تَكُونُ مِنْ خَدَمِهَا وَلاَ مِمَّنْ تَأْمَنُ عَلَى بَيْتِهَا فَدَخَلَتْ سِرًّا فَسَرَقَتْ مِنْ مَتَاعِ زَوْجِ سَيِّدَتِهَا مَا يَجِبُ فِيهِ الْقَطْعُ أَنَّهَا تُقْطَعُ يَدُهَا ‏.‏ قَالَ مَالِكٌ وَكَذَلِكَ الرَّجُلُ يَسْرِقُ مِنْ مَتَاعِ امْرَأَتِهِ أَوِ الْمَرْأَةُ تَسْرِقُ مِنْ مَتَاعِ زَوْجِهَا مَا يَجِبُ فِيهِ الْقَطْعُ إِنْ كَانَ الَّذِي سَرَقَ كُلُّ وَاحِدٍ مِنْهُمَا مِنْ مَتَاعِ صَاحِبِهِ فِي بَيْتٍ سِوَى الْبَيْتِ الَّذِي يُغْلِقَانِ عَلَيْهِمَا وَكَانَ فِي حِرْزٍ سِوَى الْبَيْتِ الَّذِي هُمَا فِيهِ فَإِنَّ مَنْ سَرَقَ مِنْهُمَا مِنْ مَتَاعِ صَاحِبِهِ مَا يَجِبُ فِيهِ الْقَطْعُ فَعَلَيْهِ الْقَطْعُ فِيهِ ‏.‏ قَالَ مَالِكٌ فِي الصَّبِيِّ الصَّغِيرِ وَالأَعْجَمِيِّ الَّذِي لاَ يُفْصِحُ أَنَّهُمَا إِذَا سُرِقَا مِنْ حِرْزِهِمَا أَوْ غَلْقِهِمَا فَعَلَى مَنْ سَرَقَهُمَا الْقَطْعُ وَإِنْ خَرَجَا مِنْ حِرْزِهِمَا وَغَلْقِهِمَا فَلَيْسَ عَلَى مَنْ سَرَقَهُمَا قَطْعٌ ‏.‏ قَالَ وَإِنَّمَا هُمَا بِمَنْزِلَةِ حَرِيسَةِ الْجَبَلِ وَالثَّمَرِ الْمُعَلَّقِ ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ عِنْدَنَا فِي الَّذِي يَنْبِشُ الْقُبُورَ أَنَّهُ إِذَا بَلَغَ مَا أَخْرَجَ مِنَ الْقَبْرِ مَا يَجِبُ فِيهِ الْقَطْعُ فَعَلَيْهِ فِيهِ الْقَطْعُ ‏.‏ وَقَالَ مَالِكٌ وَذَلِكَ أَنَّ الْقَبْرَ حِرْزٌ لِمَا فِيهِ كَمَا أَنَّ الْبُيُوتَ حِرْزٌ لِمَا فِيهَا ‏.‏ قَالَ وَلاَ يَجِبُ عَلَيْهِ الْقَطْعُ حَتَّى يَخْرُجَ بِهِ مِنَ الْقَبْرِ ‏.‏\hadithno{1532}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Abu'z-Zinad informed him that a governor of Umar ibn Abd al-Aziz took some people in battle and had not killed any of them. He wanted to cut off their hands or kill them, so he wrote to Umar ibn Abd al-Aziz about that Umar ibn Abd al-Aziz wrote to him, "Better to take less than that." Yahya said that he heard Malik say, "What is done among us about a person who steals the goods of people which are placed under guard in the markets, and their owners put them in their containers and store them together is that if anyone steals any of that from where it is kept, and its value reaches that for which cutting off the hand is obliged, his hand must be cut off, whether or not the owner of the goods is with his goods and whether it is night or day." Malik said about some one who stole something for which cutting off the hand was obliged and then what he stole was found with him and he returned it to its owner, "His hand is cut off." Malik said, "If someon says, 'How can his hand be cut off when the goods have been taken from him and returned to their owner?', it is because he is in the same position as the wine drinker when the smell of the wine is found on his breath and he is not drunk. He is flogged with the hadd. "The hadd is imposed for drinking wine even if it does not make the man intoxicated. That is because he drank it to become intoxicated. It is the same as that with cutting off the hand of the thief for theft when it is taken from him, even if he has not profited from it and it was returned to its owner. When he stole it, he stole it to take it away." Malik said that if some people came to a house and robbed it together, and then they left with a sack or box or a board or basket or the like of that which they carried together, and when they took it out of its guarded place, they carried it together, and the price of what they took reached that for which cutting off the hand was obliged, and that was three dirhams and upwards, each of them had his hand cut off. "If each of them takes out something by himself, whoever of them takes out something whose value reaches three dirhams and upwards must have his hand cut off. If any of them takes out something whose value does not reach three dirhams, he does not have his hand cut off." Yahya said that Malik said, "What is done among us is that when a man's house is locked and he is the only one living in it, cutting off the hand is not obliged against the one who steals something from it until he takes it out of the house completely. That is because all of the house is a place of custody. If someone other than him lives in the house and each of them locks his door, and it is a place of custody for each of them, whoever steals anything from the apartments of that house must have his hand cut off when he leaves the apartment and goes into the main house. He has removed it from its place of custody to another place and he must have his hand cut off." Malik said, "What is done in our community about a slave who steals from the property of his master is that if he is not in service and among those trusted in the house and he enters secretly and steals from his master something that for which cutting off the hand is obliged, his hand is not cut off. It is like that with a slave-girl when she steals from her master's property. Her hand is not cut off." Malik then spoke about a slave who was not in service and not one of those trusted in the house, and he entered secretly and stole from the property of his master's wife that for which cutting off the hand was obliged. He said, "His hand is cut off." "It is like that with the wife's slave-girl when she does not serve her or her husband nor is she trusted in the house and she enters secretly and steals from her mistress's property that for which cutting off the hand is obliged. Her hand is not cut off." "It is like that with the wife's slave-girl who is not in her service and is not trusted in the house and she enters secretly and steals from the property of her mistress's husband something for which cutting off the hand is obliged. Her hand is cut off." It is like that with the man who steals from his wife's goods or the wife who steals from her husband's goods something for which cutting off the hand is obliged. If the thing which one of them steals from his spouse's property is in a room other than the room which they both lock for themselves, or it is in a place of custody in a room other than the room which they are in, whichever of them steals something for which cutting off the hand is obliged, their hand should be cut off." Malik spoke about a small child and a foreigner who does not speak clearly. He said, "If they are robbed of something from its place of custody or from under a lock, the one who stole it has his hand cut off. If the property is outside of its place of custody or locked room(when it is stolen), the one who robbed them does not have his hand cut off. It is then in the position of sheep stolen from the mountain and uncut fruit hanging on the trees " Malik said, "What is done among us about a person who robs graves is that if what he takes from the grave reaches what cutting off the hand is obliged for, his hand is cut off . That is because the grave is a place of custody for what is in it just as houses are a place of custody for what is in them. " Malik added, "Cutting off the hand is not obliged for him until he takes it out of the grave}}
\hadithdefcmd{malik}{1533}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، أَنَّ عَبْدًا، سَرَقَ وَدِيًّا مِنْ حَائِطِ رَجُلٍ فَغَرَسَهُ فِي حَائِطِ سَيِّدِهِ فَخَرَجَ صَاحِبُ الْوَدِيِّ يَلْتَمِسُ وَدِيَّهُ فَوَجَدَهُ فَاسْتَعْدَى عَلَى الْعَبْدِ مَرْوَانَ بْنَ الْحَكَمِ فَسَجَنَ مَرْوَانُ الْعَبْدَ وَأَرَادَ قَطْعَ يَدِهِ فَانْطَلَقَ سَيِّدُ الْعَبْدِ إِلَى رَافِعِ بْنِ خَدِيجٍ فَسَأَلَهُ عَنْ ذَلِكَ فَأَخْبَرَهُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ وَالْكَثَرُ الْجُمَّارُ ‏.‏ فَقَالَ الرَّجُلُ فَإِنَّ مَرْوَانَ بْنَ الْحَكَمِ أَخَذَ غُلاَمًا لِي وَهُوَ يُرِيدُ قَطْعَهُ وَأَنَا أُحِبُّ أَنْ تَمْشِيَ مَعِيَ إِلَيْهِ فَتُخْبِرَهُ بِالَّذِي سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَمَشَى مَعَهُ رَافِعٌ إِلَى مَرْوَانَ بْنِ الْحَكَمِ فَقَالَ أَخَذْتَ غُلاَمًا لِهَذَا فَقَالَ نَعَمْ ‏.‏ فَقَالَ فَمَا أَنْتَ صَانِعٌ بِهِ قَالَ أَرَدْتُ قَطْعَ يَدِهِ ‏.‏ فَقَالَ لَهُ رَافِعٌ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ فَأَمَرَ مَرْوَانُ بِالْعَبْدِ فَأُرْسِلَ ‏.‏\hadithno{1533}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Yahya ibn Habban that a slave stole a small palm from a man's garden and planted it in the garden of his master. The owner of the palm went out looking for the palm and found it. He asked for help against the slave from Marwan ibn al-Hakam. Marwan jailed the slave and wanted to cut off his hand. The master of the slave rushed off to Rafi ibn Khadij and asked him about it. Rafi informed him that he heard the Messenger of Allah, may Allah bless him and grant him peace, say, "The hand is not cut off for fruit or palm pith." The man said, "Marwan ibn al-Hakam has taken a slave of mine and wants to cut off his hand. I would like you to go with me to him so you can tell him what you heard from the Messenger of Allah, may Allah bless him and grant him peace." So, Rafi went with him to Marwan ibn al-Hakam. He said, "Did you arrest a slave for this?" He said, "Yes." He said, "What will you do with him?" He said, "I want to cut off his hand." Rafi said to him, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'The hand is not cut off for dates or palm pith.' Marwan therefore ordered the slave to be released}}
\hadithdefcmd{malik}{1534}{حَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْحَضْرَمِيِّ، جَاءَ بِغُلاَمٍ لَهُ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ لَهُ اقْطَعْ يَدَ غُلاَمِي هَذَا فَإِنَّهُ سَرَقَ ‏.‏ فَقَالَ لَهُ عُمَرُ مَاذَا سَرَقَ فَقَالَ سَرَقَ مِرْآةً لاِمْرَأَتِي ثَمَنُهَا سِتُّونَ دِرْهَمًا ‏.‏ فَقَالَ عُمَرُ أَرْسِلْهُ فَلَيْسَ عَلَيْهِ قَطْعٌ خَادِمُكُمْ سَرَقَ مَتَاعَكُمْ ‏.‏\hadithno{1534}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from as-Sa'ib ibn Yazid that Abdullah ibn Amr ibn al-Hadrami brought a slave of his to Umar ibn al-Khattab and said to him, "Cut off the hand of this slave of mine. He has stolen." Umar said to him, "What did he steal?" He said, "He stole a mirror belonging to my wife. Its value was sixty dirhams." Umar said, "Let him go. His hand is not to be cut off. He is your servant who has stolen your belongings}}
\hadithdefcmd{malik}{1535}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، أُتِيَ بِإِنْسَانٍ قَدِ اخْتَلَسَ مَتَاعًا فَأَرَادَ قَطْعَ يَدِهِ فَأَرْسَلَ إِلَى زَيْدِ بْنِ ثَابِتٍ يَسْأَلُهُ عَنْ ذَلِكَ فَقَالَ زَيْدُ بْنُ ثَابِتٍ لَيْسَ فِي الْخُلْسَةِ قَطْعٌ ‏.‏\hadithno{1535}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Marwan ibn al-Hakam was brought a man who had snatched some goods and he wanted to cut off his hand. He sent to Zayd ibn Thabit to ask him about it. Zayd ibn Thabit said to him, "The hand is not cut off for what is stolen by chance, openly, in haste}}
\hadithdefcmd{malik}{1536}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّهُ أَخَذَ نَبَطِيًّا قَدْ سَرَقَ خَوَاتِمَ مِنْ حَدِيدٍ فَحَبَسَهُ لِيَقْطَعَ يَدَهُ فَأَرْسَلَتْ إِلَيْهِ عَمْرَةُ بِنْتُ عَبْدِ الرَّحْمَنِ مَوْلاَةً لَهَا يُقَالُ لَهَا أُمَيَّةُ قَالَ أَبُو بَكْرٍ فَجَاءَتْنِي وَأَنَا بَيْنَ ظَهْرَانَىِ النَّاسِ فَقَالَتْ تَقُولُ لَكَ خَالَتُكَ عَمْرَةُ يَا ابْنَ أُخْتِي أَخَذْتَ نَبَطِيًّا فِي شَىْءٍ يَسِيرٍ ذُكِرَ لِي فَأَرَدْتَ قَطْعَ يَدِهِ قُلْتُ نَعَمْ ‏.‏ قَالَتْ فَإِنَّ عَمْرَةَ تَقُولُ لَكَ لاَ قَطْعَ إِلاَّ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏ قَالَ أَبُو بَكْرٍ فَأَرْسَلْتُ النَّبَطِيَّ ‏.‏ قَالَ مَالِكٌ وَالأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا فِي اعْتِرَافِ الْعَبِيدِ أَنَّهُ مَنِ اعْتَرَفَ مِنْهُمْ عَلَى نَفْسِهِ بِشَىْءٍ يَقَعُ الْحَدُّ وَالْعُقُوبَةُ فِيهِ فِي جَسَدِهِ ‏.‏ فَإِنَّ اعْتِرَافَهُ جَائِزٌ عَلَيْهِ وَلاَ يُتَّهَمُ أَنْ يُوقِعَ عَلَى نَفْسِهِ هَذَا ‏.‏ قَالَ مَالِكٌ وَأَمَّا مَنِ اعْتَرَفَ مِنْهُمْ بِأَمْرٍ يَكُونُ غُرْمًا عَلَى سَيِّدِهِ فَإِنَّ اعْتِرَافَهُ غَيْرُ جَائِزٍ عَلَى سَيِّدِهِ ‏.‏ قَالَ مَالِكٌ لَيْسَ عَلَى الأَجِيرِ وَلاَ عَلَى الرَّجُلِ يَكُونَانِ مَعَ الْقَوْمِ يَخْدُمَانِهِمْ إِنْ سَرَقَاهُمْ قَطْعٌ لأَنَّ حَالَهُمَا لَيْسَتْ بِحَالِ السَّارِقِ وَإِنَّمَا حَالُهُمَا حَالُ الْخَائِنِ وَلَيْسَ عَلَى الْخَائِنِ قَطْعٌ ‏.‏ قَالَ مَالِكٌ فِي الَّذِي يَسْتَعِيرُ الْعَارِيَةَ فَيَجْحَدُهَا إِنَّهُ لَيْسَ عَلَيْهِ قَطْعٌ وَإِنَّمَا مَثَلُ ذَلِكَ مَثَلُ رَجُلٍ كَانَ لَهُ عَلَى رَجُلٍ دَيْنٌ فَجَحَدَهُ ذَلِكَ فَلَيْسَ عَلَيْهِ فِيمَا جَحَدَهُ قَطْعٌ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا فِي السَّارِقِ يُوجَدُ فِي الْبَيْتِ قَدْ جَمَعَ الْمَتَاعَ وَلَمْ يَخْرُجْ بِهِ إِنَّهُ لَيْسَ عَلَيْهِ قَطْعٌ وَإِنَّمَا مَثَلُ ذَلِكَ كَمَثَلِ رَجُلٍ وَضَعَ بَيْنَ يَدَيْهِ خَمْرًا لِيَشْرَبَهَا فَلَمْ يَفْعَلْ فَلَيْسَ عَلَيْهِ حَدٌّ وَمِثْلُ ذَلِكَ رَجُلٌ جَلَسَ مِنِ امْرَأَةٍ مَجْلِسًا وَهُوَ يُرِيدُ أَنْ يُصِيبَهَا حَرَامًا فَلَمْ يَفْعَلْ وَلَمْ يَبْلُغْ ذَلِكَ مِنْهَا فَلَيْسَ عَلَيْهِ أَيْضًا فِي ذَلِكَ حَدٌّ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّهُ لَيْسَ فِي الْخُلْسَةِ قَطْعٌ بَلَغَ ثَمَنُهَا مَا يُقْطَعُ فِيهِ أَوْ لَمْ يَبْلُغْ ‏.‏\hadithno{1536}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that Abu Bakr ibn Muhammad ibn Amr ibn Hazm informed him that he had taken a Nabatean who had stolen some iron rings and jailed him in order to cut off his hand. Amra bint Abd ar-Rahman sent a girl mawla to him called Umayya. Abu Bakr said that she had come to him while he was among the people and said that his aunt Amra sent word to him saying, "Son of my brother! You have taken a Nabatean for something insignificant which was mentioned to me. Do you want to cut off his hand?" He had said, "Yes." She said, ''Amra says to you not to cut off the hand except for a quarter of a dinar and upwards." Abu Bakr added, "So I let the Nabatean go." Malik said, "The generally agreed on way of doing things among us about the confession of slaves is that if a slave confesses something against himself, the hadd and punishment for it is inflicted on his body. His confession is accepted from him and one does not suspect that he would inflict something on himself." Malik said, "As for the one of them who confesses to a matter which will incur damages agains this master, his confession is not accepted against his master." Malik said, "One does not cut off the hand of a hireling or a man who is with some people to serve them, if he robs them, because his state is not the state of a thief. His state is the state of a treacherous one. The treacherous one does not have his hand cut off." Malik said about a person who borrows something and then denies it, "His hand is not cut off. He is like a man who owes a debt to another man and denies it. He does not have his hand cut off for what he has denied." Malik said, "The generally agreed-on way of dealing among us, with the thief who is found in a house and has gathered up goods and has not taken them out, is that his hand is not cut off. That is like the man who places wine before him to drink it and does not do it. The hadd is not imposed on him. That is like a man who sits with a woman and desires to have haram intercourse with her and does not do it and he does not reach her. There is no hadd against that either." Malik said, "The generally agreed-on way of doing things among us is that there is no cutting off the hand for what is taken by chance, openly and in haste, whether or not its price reaches that for which the hand is cut off}}
